# This file was automatically generated by SWIG (http://www.swig.org).
# Version 3.0.12
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info >= (2, 7, 0):
    def swig_import_helper():
        import importlib
        pkg = __name__.rpartition('.')[0]
        mname = '.'.join((pkg, '_verovio')).lstrip('.')
        try:
            return importlib.import_module(mname)
        except ImportError:
            return importlib.import_module('_verovio')
    _verovio = swig_import_helper()
    del swig_import_helper
elif _swig_python_version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_verovio', [dirname(__file__)])
        except ImportError:
            import _verovio
            return _verovio
        try:
            _mod = imp.load_module('_verovio', fp, pathname, description)
        finally:
            if fp is not None:
                fp.close()
        return _mod
    _verovio = swig_import_helper()
    del swig_import_helper
else:
    import _verovio
del _swig_python_version_info

try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr(self, class_type, name):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    raise AttributeError("'%s' object has no attribute '%s'" % (class_type.__name__, name))


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except __builtin__.Exception:
    class _object:
        pass
    _newclass = 0

uNKNOWN = _verovio.uNKNOWN
aUTO = _verovio.aUTO
mEI = _verovio.mEI
hUMDRUM = _verovio.hUMDRUM
pAE = _verovio.pAE
aBC = _verovio.aBC
dARMS = _verovio.dARMS
mUSICXML = _verovio.mUSICXML
mUSICXMLHUM = _verovio.mUSICXMLHUM
mEIHUM = _verovio.mEIHUM
mUSEDATAHUM = _verovio.mUSEDATAHUM
eSAC = _verovio.eSAC
mIDI = _verovio.mIDI
tIMEMAP = _verovio.tIMEMAP

def setDefaultResourcePath(path):
    return _verovio.setDefaultResourcePath(path)
setDefaultResourcePath = _verovio.setDefaultResourcePath
class toolkit(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, toolkit, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, toolkit, name)
    __repr__ = _swig_repr

    def __init__(self, initFont=True):
        this = _verovio.new_toolkit(initFont)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _verovio.delete_toolkit
    __del__ = lambda self: None

    def getUuid(self):
        return _verovio.toolkit_getUuid(self)

    def setResourcePath(self, path):
        return _verovio.toolkit_setResourcePath(self, path)

    def loadFile(self, filename):
        return _verovio.toolkit_loadFile(self, filename)

    def loadData(self, data):
        return _verovio.toolkit_loadData(self, data)

    def saveFile(self, filename, jsonOptions):
        return _verovio.toolkit_saveFile(self, filename, jsonOptions)

    def getOptions(self, *args):
        return _verovio.toolkit_getOptions(self, *args)

    def getAvailableOptions(self):
        return _verovio.toolkit_getAvailableOptions(self)

    def setOptions(self, jsonOptions):
        return _verovio.toolkit_setOptions(self, jsonOptions)

    def getOption(self, option, defaultValue=False):
        return _verovio.toolkit_getOption(self, option, defaultValue)

    def setOption(self, option, value):
        return _verovio.toolkit_setOption(self, option, value)

    def edit(self, json_editorAction):
        return _verovio.toolkit_edit(self, json_editorAction)

    def editInfo(self):
        return _verovio.toolkit_editInfo(self)

    def getLog(self):
        return _verovio.toolkit_getLog(self)

    def getVersion(self):
        return _verovio.toolkit_getVersion(self)

    def renderToDeviceContext(self, pageNo, deviceContext):
        return _verovio.toolkit_renderToDeviceContext(self, pageNo, deviceContext)

    def renderToSVG(self, pageNo=1, xml_declaration=False):
        return _verovio.toolkit_renderToSVG(self, pageNo, xml_declaration)

    def renderToSVGFile(self, filename, pageNo=1):
        return _verovio.toolkit_renderToSVGFile(self, filename, pageNo)

    def renderToMIDIFile(self, filename):
        return _verovio.toolkit_renderToMIDIFile(self, filename)

    def renderToMIDI(self):
        return _verovio.toolkit_renderToMIDI(self)

    def renderToPAEFile(self, filename):
        return _verovio.toolkit_renderToPAEFile(self, filename)

    def renderToPAE(self):
        return _verovio.toolkit_renderToPAE(self)

    def renderToTimemap(self):
        return _verovio.toolkit_renderToTimemap(self)

    def renderToTimemapFile(self, filename):
        return _verovio.toolkit_renderToTimemapFile(self, filename)

    def getHumdrumBuffer(self):
        return _verovio.toolkit_getHumdrumBuffer(self)

    def setHumdrumBuffer(self, contents):
        return _verovio.toolkit_setHumdrumBuffer(self, contents)

    def getHumdrumFile(self, filename):
        return _verovio.toolkit_getHumdrumFile(self, filename)

    def getHumdrum(self, *args):
        return _verovio.toolkit_getHumdrum(self, *args)

    def getElementsAtTime(self, millisec):
        return _verovio.toolkit_getElementsAtTime(self, millisec)

    def getMEI(self, jsonOptions):
        return _verovio.toolkit_getMEI(self, jsonOptions)

    def getElementAttr(self, xmlId):
        return _verovio.toolkit_getElementAttr(self, xmlId)

    def getNotatedIdForElement(self, xmlId):
        return _verovio.toolkit_getNotatedIdForElement(self, xmlId)

    def getExpansionIdsForElement(self, xmlId):
        return _verovio.toolkit_getExpansionIdsForElement(self, xmlId)

    def redoLayout(self):
        return _verovio.toolkit_redoLayout(self)

    def redoPagePitchPosLayout(self):
        return _verovio.toolkit_redoPagePitchPosLayout(self)

    def getPageWithElement(self, xmlId):
        return _verovio.toolkit_getPageWithElement(self, xmlId)

    def getTimeForElement(self, xmlId):
        return _verovio.toolkit_getTimeForElement(self, xmlId)

    def getMIDIValuesForElement(self, xmlId):
        return _verovio.toolkit_getMIDIValuesForElement(self, xmlId)

    def setScale(self, scale):
        return _verovio.toolkit_setScale(self, scale)

    def getScale(self):
        return _verovio.toolkit_getScale(self)

    def setInputFrom(self, *args):
        return _verovio.toolkit_setInputFrom(self, *args)

    def getInputFrom(self):
        return _verovio.toolkit_getInputFrom(self)

    def setOutputTo(self, outputTo):
        return _verovio.toolkit_setOutputTo(self, outputTo)

    def getOutputTo(self):
        return _verovio.toolkit_getOutputTo(self)

    def identifyInputFrom(self, data):
        return _verovio.toolkit_identifyInputFrom(self, data)

    def getPageCount(self):
        return _verovio.toolkit_getPageCount(self)
    __swig_setmethods__["sMEItoClassIdMap"] = _verovio.toolkit_sMEItoClassIdMap_set
    __swig_getmethods__["sMEItoClassIdMap"] = _verovio.toolkit_sMEItoClassIdMap_get
    if _newclass:
        sMEItoClassIdMap = _swig_property(_verovio.toolkit_sMEItoClassIdMap_get, _verovio.toolkit_sMEItoClassIdMap_set)
toolkit_swigregister = _verovio.toolkit_swigregister
toolkit_swigregister(toolkit)
cvar = _verovio.cvar

# This file is compatible with both classic and new-style classes.





#!/usr/bin/env python

"""
setup.py file for Verovio
"""

from setuptools import setup, Extension
from setuptools.command.build_ext import build_ext as _build_ext
from setuptools.command.sdist import sdist as _sdist
from glob import glob
import platform
import os
import subprocess

def get_commit():
    """Utility function to call tools/get_git_commit.sh on any platform"""
    if os.path.exists("./tools"):
        print("Running tools/get_git_commit.sh")
        os.system("bash -c 'cd tools; ./get_git_commit.sh'")
    else:
        print("Can't change to tools directory")

class build_ext(_build_ext):
    """Override build_ext and sdist commands to generate the git version header file"""
    def run(self):
        # generate the git commit include file
        get_commit()
        _build_ext.run(self)

class sdist(_sdist):
    """Override build_sdist and sdist commands to generate the git version header file"""
    def run(self):
        # generate the git commit include file
        get_commit()
        _sdist.run(self)

# Utility function to read the README file into the long_description.
with open('README.md', 'r') as fh:
    long_description = fh.read()

def get_version():
    """Function to get the version from the cpp file and the git sha for dev versions"""
    version = "0.0.0"
    # If we have a PKG-INFO (e.g., in a sdist) use that
    if os.path.exists('PKG-INFO'):
        with open('PKG-INFO', 'r') as f:
            lines = f.readlines()
        for line in lines:
            if line.startswith('Version:'):
                return line[8:].strip()
    if os.path.exists("./tools"):
        print("Running tools/get_version.sh")
        version = subprocess.getoutput("bash -c 'cd tools; ./get_version.sh'")
    if version.endswith(".dev"):
        init_sha = subprocess.getoutput("git log -n 1 --pretty=format:%H -- bindings/python/.pypi-version")
        count = subprocess.getoutput("git rev-list --count HEAD \"^{}\"".format(init_sha))
        version += count
    print(version)
    return version

# extra compile arguments
EXTRA_COMPILE_ARGS = ['-DPYTHON_BINDING']
if platform.system() != 'Windows':
    EXTRA_COMPILE_ARGS += ['-std=c++17',
                           '-Wno-write-strings', '-Wno-overloaded-virtual']
else:
    EXTRA_COMPILE_ARGS += ['/std:c++17',
                           '-DNO_PAE_SUPPORT']

verovio_module = Extension('verovio._verovio',
                           sources=glob('./src/*.cpp') + glob('./src/hum/*.cpp') +
                                   [
                                       './src/json/jsonxx.cc',
                                       './src/pugi/pugixml.cpp',
                                       './src/midi/Binasc.cpp',
                                       './src/midi/MidiEvent.cpp',
                                       './src/midi/MidiEventList.cpp',
                                       './src/midi/MidiFile.cpp',
                                       './src/midi/MidiMessage.cpp',
                                       './libmei/attconverter.cpp',
                                       './libmei/atts_analytical.cpp',
                                       './libmei/atts_cmn.cpp',
                                       './libmei/atts_cmnornaments.cpp',
                                       './libmei/atts_critapp.cpp',
                                       './libmei/atts_gestural.cpp',
                                       './libmei/atts_externalsymbols.cpp',
                                       './libmei/atts_facsimile.cpp',
                                       './libmei/atts_mei.cpp',
                                       './libmei/atts_mensural.cpp',
                                       './libmei/atts_midi.cpp',
                                       './libmei/atts_neumes.cpp',
                                       './libmei/atts_pagebased.cpp',
                                       './libmei/atts_shared.cpp',
                                       './libmei/atts_visual.cpp',
                                       './bindings/python/verovio.i'],
                           swig_opts=['-c++', '-outdir', './bindings/python'],
                           include_dirs=['/usr/local/include',
                                         './include',
                                         './include/vrv',
                                         './include/json',
                                         './include/midi',
                                         './include/hum',
                                         './include/pugi',
                                         './include/utf8',
                                         './include/win32',
                                         './libmei'],
                           extra_compile_args=EXTRA_COMPILE_ARGS
                           )


setup(name='verovio',
      version = get_version(),
      cmdclass={'sdist': sdist, 'build_ext': build_ext},
      url="https://www.verovio.org",
      description="""A library and toolkit for engraving MEI music notation into SVG""",
      long_description=long_description,
      long_description_content_type="text/markdown",
      ext_modules=[verovio_module],
      packages=['verovio',
                'verovio.data',
                'verovio.data.Bravura',
                'verovio.data.Gootville',
                'verovio.data.Leipzig',
                'verovio.data.Petaluma',
                'verovio.data.text'],
      # cf. https://docs.python.org/3/distutils/examples.html#pure-python-distribution-by-package
      package_dir={'verovio': './bindings/python',
                   'verovio.data': './data'},
      package_data={
          'verovio.data': [f for f in os.listdir('./data') if f.endswith(".xml")],
          'verovio.data.Bravura': os.listdir('./data/Bravura'),
          'verovio.data.Gootville': os.listdir('./data/Gootville'),
          'verovio.data.Leipzig': os.listdir('./data/Leipzig'),
          'verovio.data.Petaluma': os.listdir('./data/Petaluma'),
          'verovio.data.text': os.listdir('./data/text'),
      }
)
